@@ -95,6 +95,7 @@ try:
 except:
 	has_numpy = False
 
+__version__ = '1.0.1'
 
 def NoneStr(obj): return 'NULL'
 
@@ -201,7 +202,7 @@ class RError(Exception):
 	def __str__(self):
 		return repr(self.value)
 
-class R(object):
+class R: # (object):
 	'''
 	A Python class to enclose an R process.
 	'''
@@ -286,10 +287,23 @@ class R(object):
 		return(NullStr(x)) }
 	Str4Py(x)
 	}
+	# initalize library path for TCL/TK based environment on Windows, e.g. Python IDLE
+	.addLibs <- function() {
+		ruser <- Sys.getenv('R_USER')
+		userpath <- Sys.getenv('R_LIBS_USER')
+		libpaths <- .libPaths()
+		for (apath in userpath) {
+			if (length(grep(apath, libpaths)) > 0) next
+			apath <- paste(ruser, '/Documents', substr(apath, nchar(ruser)+1, nchar(apath)), sep='')
+			.libPaths(apath)
+			}
+		}
+	if(identical(.Platform$OS.type, 'windows')) .addLibs()
+	rm(.addLibs)
 	''' 
 	_DEBUG_MODE = True
 
-	def __init__(self, RCMD='R', wait0=2, wait=0.01, max_len=1000, use_numpy=True, host='localhost', user=None, ssh='ssh'):
+	def __init__(self, RCMD='R', wait0=2, wait=0.01, max_len=1000, use_numpy=True, host='localhost', user=None, ssh='ssh', return_err=True):
 		'''
 		RCMD: The name of a R interpreter, path information should be included
 			if it is not in the system search path.
@@ -313,22 +327,41 @@ class R(object):
 			by the user if prompted. If running in a program, the user needs to
 			be able to login without typing password! 
 		ssh: The program to login to remote computer.
-		'''
+		return_err: redict stderr to stdout
+		''' 
+		# use self.__dict__.update to register variables since __setattr__ is
+		# used to set variables for R.  tried to define __setattr in the class,
+		# and change it to __setattr__ for instances at the end of __init__,
+		# but it seems failed.
+		# -- maybe this only failed in Python2.5? as warned at
+		# http://wiki.python.org/moin/NewClassVsClassicClass: 
+		# "Warning: In 2.5, magic names (typically those with a double
+		# underscore (DunderAlias) at both ends of the name) may look at the
+		# class rather than the instance even for old-style classes."
 		self.__dict__.update({
 			'wait0':wait0, 
 			'wait':wait, 
 			'max_len':max_len, 
 			'localhost':host=='localhost', 
 			'tail':sys.platform=='win32' and '\r\n' or '\n'})
-		if not re.search(r'\s--vanilla\b', RCMD): RCMD = RCMD + ' --vanilla'
+
 		RCMD = shlex.split(RCMD) #re.split(r'\s', RCMD)
 		if not self.localhost:
 			RCMD.insert(0, host)
 			if user:
 				RCMD.insert(0, '-l%s' % user)
 			RCMD.insert(0, ssh)
+		#args = ('--vanilla',) # equal to --no-save, --no-restore, --no-site-file, --no-init-file and --no-environ
+		args = ('--quiet', '--no-save', '--no-restore') # "--slave" cannot be used on Windows!
+		for arg in args:
+			if arg not in RCMD: RCMD.append(arg)
+		if hasattr(subprocess, 'STARTUPINFO'):
+			info = subprocess.STARTUPINFO()
+			info.dwFlags |= subprocess.STARTF_USESHOWWINDOW
+			info.wShowWindow = subprocess.SW_HIDE
+		else: info = None
 		self.__dict__.update({
-			'prog':Popen(RCMD, stdin=PIPE, stdout=PIPE), 
+			'prog':Popen(RCMD, stdin=PIPE, stdout=PIPE, stderr=return_err and subprocess.STDOUT or None, startupinfo=info), 
 			'has_numpy':use_numpy and has_numpy, 
 			'Rfun':self.__class__.__Rfun % ((use_numpy and has_numpy) and 'TRUE' or 'FALSE')})
 		self.__call__(self.Rfun)
@@ -343,6 +376,7 @@ class R(object):
 		tail_token = 'R command at time: %s' % repr(time.time())
 		tail_cmd = 'print("%s")%s' % (tail_token, tail)
 		rlt_tail = '> print("%s")%s[1] "%s"%s> ' % (tail_token, tail, tail_token, tail)
+		rlt_tail1 = rlt_tail.replace('\r', '') # sometimes Windows use '\n' only, e.g. after "library(fastICA)"!
 		#if not CMD.endswith(tail): CMD = CMD + tail
 		if len(CMD) <= self.max_len or not self.localhost: 
 			fn = None
@@ -353,7 +387,7 @@ class R(object):
 		CMD = (use_try and 'try({%s})%s%s' or '%s%s%s') % (CMD, tail, tail_cmd)
 		send_all(self.prog, CMD)
 		rlt = ''
-		while not rlt.endswith(rlt_tail):
+		while not rlt.endswith(rlt_tail) and not rlt.endswith(rlt_tail1):
 			try:
 				rltonce = recv_some(self.prog, e=1, t=self.wait)
 				if rltonce: rlt = rlt + rltonce
